/* 
 * File: MainController.js
 * Containing controller
 */

/*jslint node: true, vars: true, bitwise: true */
/*global angular, MeasuringCore. MeasuringCore_ViewModel */
/* find out more about jslint: http://www.jslint.com/help.html */

"use strict";

// disable right mouse button context menur
// http://stackoverflow.com/questions/10864249/disabling-right-click-context-menu-on-a-html-canvas


// Creates the "backend" logical support for appMyExample
var myModule = angular.module("appMyMP2", ["CSS450Timer", "CSS450Slider"]);

// registers the constructor for the controller
// NOTE: the constructor is only called _AFTER_ the </body> tag is encountered
//       this code does NOT run until the end of loading the HTML page
myModule.controller("MainCtrl", function ($scope) {
    // 
    $scope.mModel = new MeasuringCore();
    $scope.mViewModel = new MeasuringCore_ViewModel($scope.mModel);
    $scope.mModel.setViewModel($scope.mViewModel);
    
    // Timer support
    $scope.mElapsedTime = 0;
    $scope.mSessionEnabled = false;
    
    // mouse stuff
    $scope.mMouseX = 0;
    $scope.mMouseY = 0;
    $scope.mLMBClickX = 0;
    $scope.mLMBClickY = 0;
    
    $scope.serviceDown = function(event) {
        switch (event.which) {
            case 1: // left mouse button
            $scope.mLMBClickX = event.clientX;
            $scope.mLMBClickY = event.clientY;
            $scope.mModel.addMeasurementPoint(event.clientX, event.clientY);
            break;
            
            case 3: // right mouse
                if ($scope.mModel.isMeasuringEnabled())
                    $scope.mModel.doneMeasurement();
                break;
        } 
    };
    $scope.serviceMove = function(event) {
        $scope.mMouseX = event.clientX;
        $scope.mMouseY = event.clientY;
    };
    
    $scope.changeUnit = function () {
        $scope.mViewModel.setUnitString();
        $scope.setScale();
    };
    
    $scope.updateTimer = function() {
        $scope.mElapsedTime += 1;
    };
    
    $scope.toggleSession = function() {
        $scope.mModel.toggleMeasureState();
        $scope.mElapsedTime = 0;
        if ($scope.mSessionEnabled) {
            $scope.$broadcast("timer-started");
        } else {
            $scope.$broadcast("timer-stopped");
        }
    };
    
    $scope.setScale = function() {
        $scope.mViewModel.pushScaleToModel();
        $scope.mViewModel.setMeasureResults();
    };
});
