/* 
 * File: MeasuringCore.js
 * The Model Object
 */

/*jslint node: true, vars: true, bitwise: true */
/*global angular */
/* find out more about jslint: http://www.jslint.com/help.html */

"use strict";

function MeasuringCore() {
    this.mViewModel = null;

    this.sUnitString = [
        " Pixel", " Millimeters", " Centimeters", " Meters"
    ];

    this.sUnitScale = [ 1, 5, 10, 50];

    this.sStatusMessage = [
        " Measurement Disabled",
        " Measuring in Progress: before first click",
        " Measuring in Progress: Number of LMB Clicks: ",
        " Measuring has Ended: Total number of LMB Clicks: "
    ];

    this.mMeasureState = MeasuringCore.eMeasureState.eMeasureStateDisabled;

    // this is the measuring state
    this.mScale = 1.0;
    this.mCurrentPoint = [0, 0];

    this.initMeasureSession();
}

MeasuringCore.eMeasureState = Object.freeze({
    eMeasureStateDisabled: 0,
    eMeasureStateEnabled: 1,
    eMeasureStateInProgress: 2,
    eMeasureStateEnded: 3
});

MeasuringCore.eMeasureUnit = Object.freeze({
    eMeasurePixel: 0,
    eMeasureMM: 1,
    eMeasureCM: 2,
    eMeasureM: 3
});


MeasuringCore.prototype.setViewModel = function (vm) { 
    this.mViewModel = vm;
    this.mViewModel.setStateString(this.mMeasureState, this.mNumPoints);
    this.mViewModel.setUnitString();
};

// behaviors
MeasuringCore.prototype.initMeasureSession = function () {
    this.mNumPoints = 0;
    this.mDistance = 0.0;
};

MeasuringCore.prototype.toggleMeasureState = function () {
    if (this.isMeasuringEnabled())
        this.mMeasureState = MeasuringCore.eMeasureState.eMeasureStateDisabled;
    else
        this.mMeasureState = MeasuringCore.eMeasureState.eMeasureStateEnabled;
    this.mViewModel.setStateString(this.mMeasureState, this.mNumPoints);
    this.initMeasureSession();
    
};

MeasuringCore.prototype.isMeasuringEnabled = function () {
    return (this.mMeasureState !== MeasuringCore.eMeasureState.eMeasureStateDisabled);
};

MeasuringCore.prototype.setPixelScale = function (scale) {
    this.mScale = scale;
};
MeasuringCore.prototype.setMeasureUnit = function (u) {
    this.mMeasureUnit = u;
    this.setPixelScale(this.sUnitScale[u]);
    this.mViewModel.setScaleTo(this.mScale);
};

MeasuringCore.prototype.addMeasurementPoint = function (x, y) {
    if (this.isMeasuringEnabled()) {
        if (this.mMeasureState === MeasuringCore.eMeasureState.eMeasureStateEnded)
            this.initMeasureSession();
        this.mMeasureState = MeasuringCore.eMeasureState.eMeasureStateInProgress;
        this.mNumPoints += 1;
        if (this.mNumPoints > 1) {
            var dx = this.mCurrentPoint[0] - x;
            var dy = this.mCurrentPoint[1] - y;
            this.mDistance += Math.sqrt(dx * dx + dy * dy);
            this.mCurrentPoint[0] = x;
            this.mCurrentPoint[1] = y;
        }
        this.mViewModel.setStateString(this.mMeasureState, this.mNumPoints);
        this.mViewModel.setMeasureResults();
    }
};

MeasuringCore.prototype.doneMeasurement = function () {
    this.mMeasureState = MeasuringCore.eMeasureState.eMeasureStateEnded;
    this.mViewModel.setStateString(this.mMeasureState, this.mNumPoints);
};
MeasuringCore.prototype.getMeasurementInPixel  = function () {
    return this.mDistance;
};
MeasuringCore.prototype.getMeasurementInUnit = function () {
    return this.mDistance * this.mScale;
};