/* 
 * File: MeasuringCore_ViewModel.js
 * View's model for interfacing to the actualy model
 */

/*jslint node: true, vars: true, bitwise: true */
/*global angular, MeasuringCore */
/* find out more about jslint: http://www.jslint.com/help.html */

"use strict";

function MeasuringCore_ViewModel(theModel) {
    this.mTheModel = theModel;

    // view's model interface
    this.vmMeasureUnit = MeasuringCore.eMeasureUnit.eMeasurePixel;
    this.vmUnitString = theModel.sUnitString[0];
    this.vmMeasureUnitRadio = [
        {code: MeasuringCore.eMeasureState.eMeasureStateDisabled,    name: theModel.sUnitString[0]},
        {code: MeasuringCore.eMeasureState.eMeasureStateEnabled,     name: theModel.sUnitString[1]},
        {code: MeasuringCore.eMeasureState.eMeasureStateInProgress,  name: theModel.sUnitString[2]},
        {code: MeasuringCore.eMeasureState.eMeasureStateEnded,       name: theModel.sUnitString[3]}
    ];

    this.vmStateString = null;

    this.vmMeasureScale = 1;

    this.vmMeasuredPixel = null;
    this.vmMeasuredUnit = null;
    this.setMeasureResults();
    this.setStateString(MeasuringCore.eMeasureState.eMeasureStateDisabled, 0);
}

MeasuringCore_ViewModel.prototype.setStateString = function (state, numPoints) {
    this.vmStateString = this.mTheModel.sStatusMessage[state];
    if ((state === MeasuringCore.eMeasureState.eMeasureStateInProgress) ||
        (state === MeasuringCore.eMeasureState.eMeasureStateEnded) )
        this.vmStateString += numPoints;
};

MeasuringCore_ViewModel.prototype.setUnitString = function() {
    this.mTheModel.setMeasureUnit(this.vmMeasureUnit);
    this.vmUnitString = this.mTheModel.sUnitString[this.vmMeasureUnit];
};

MeasuringCore_ViewModel.prototype.setMeasureResults = function() {
    this.vmMeasuredPixel = this.mTheModel.getMeasurementInPixel().toFixed(3);
    this.vmMeasuredUnit = this.mTheModel.getMeasurementInUnit().toFixed(3);
};

MeasuringCore_ViewModel.prototype.setScaleTo = function(s) {
    this.vmMeasureScale = s;
};
MeasuringCore_ViewModel.prototype.pushScaleToModel = function() {
    this.mTheModel.setPixelScale(this.vmMeasureScale);
};